@@ -126,7 +126,7 @@ class ImgListDelegate(QAbstractItemDelegate):
         self.view = parent
         # TODO: move as_circle/w_h_ratio attribute to view
         self.as_circle = True
-        self.w_h_ratio = 1
+        self.w_h_ratio = 1.0
 
     def paint(self, painter, option, index):
         painter.save()
@@ -184,7 +184,7 @@ class ImgListDelegate(QAbstractItemDelegate):
             source_option.setAlignment(Qt.AlignLeft | Qt.AlignTop)
         name = index.data(Qt.DisplayRole)
         fm = QFontMetrics(painter.font())
-        elided_name = fm.elidedText(name, Qt.ElideRight, text_rect.width())
+        elided_name = fm.elidedText(name, Qt.ElideRight, int(text_rect.width()))
         source = index.data(Qt.WhatsThisRole)
         painter.drawText(text_rect, elided_name, option)
         painter.restore()
