@@ -17,7 +17,6 @@ from PyQt5.QtWidgets import (
 
 from feeluown.utils import aio
 from feeluown.utils.dispatch import Signal
-from feeluown.excs import ProviderIOError
 from feeluown.library import ModelState, ModelFlags
 from feeluown.models import ModelExistence
 
@@ -60,7 +59,10 @@ class ColumnsConfig:
         self._widths[column] = ratio
 
     def get_width(self, column, table_width):
-        width_index = 10
+        # Note(cosven): On macOS, 36px is available to show three number.
+        # On KDE, even if we set the width to 10px, it does not ellipse the text.
+        # In conclusion, I think 36px is good for macOS and KDE.
+        width_index = 36
         if column == Column.index:
             return width_index
         width = table_width - width_index
@@ -76,7 +78,10 @@ class ColumnsConfig:
             Column.song: 0.4,
             Column.artist: 0.15,
             Column.album: 0.25,
-            Column.duration: 0.05,
+            # Note(cosven): Generally, the duration text is about 5 char, like 00:00.
+            # On macOS with default font, I found the width of such text is about 55px.
+            # The songs table width is about 600px, so set duration ratio to 0.1.
+            Column.duration: 0.1,
             Column.source: 0.15,
         }
         return cls(widths=widths)
@@ -238,17 +243,14 @@ class BaseSongsTableModel(QAbstractTableModel):
         if index.column() in (Column.source, Column.index, Column.duration):
             return no_item_flags
 
-        # default flags
-        flags = Qt.ItemIsSelectable | Qt.ItemIsEnabled
-        if index.column() == Column.song:
-            flags |= Qt.ItemIsDragEnabled
-
+        # Default flags.
+        flags = Qt.ItemIsSelectable | Qt.ItemIsEnabled | Qt.ItemIsDragEnabled
         song = index.data(Qt.UserRole)
         # If song's state is `not_exists` or `cant_upgrade`, the album and
         # artist columns are disabled.
         incomplete = False
         if ModelFlags.v2 & song.meta.flags:
-            if song.state is (ModelState.not_exists, ModelState.cant_upgrade):
+            if song.state in (ModelState.not_exists, ModelState.cant_upgrade):
                 incomplete = True
         else:
             if song and song.exists == ModelExistence.no:
@@ -297,7 +299,7 @@ class BaseSongsTableModel(QAbstractTableModel):
         if role in (Qt.DisplayRole, Qt.ToolTipRole):
             # Only show tooltip for song/artist/album fields.
             if role == Qt.ToolTipRole and index.column() not in \
-               (Column.song, Column.artist, Column.album):
+               (Column.song, Column.artist, Column.album, Column.duration):
                 return QVariant()
             if index.column() == Column.index:
                 return index.row() + 1
@@ -324,15 +326,15 @@ class BaseSongsTableModel(QAbstractTableModel):
         return QVariant()
 
     def mimeData(self, indexes):
-        if len(indexes) == 1:
+        # When the selection behaviour is set to QAbstractItemView.SelectRows,
+        # len(indexes) is equal to length of items which have ItemIsDragEnabled flag.
+        indexes = list(indexes)  # Make typing checkers happy.
+        if len(indexes) > 1:
+            # UserRole data of all indexes should be the same,
+            # so just use the a random one.
             index = indexes[0]
-            model = song = index.data(Qt.UserRole)
-            if index.column() == Column.album:
-                try:
-                    model = song.album
-                except (ProviderIOError, Exception):
-                    model = None
-            return ModelMimeData(model)
+            song = index.data(Qt.UserRole)
+            return ModelMimeData(song)
 
 
 class SongsTableModel(BaseSongsTableModel, ReaderFetchMoreMixin):
@@ -600,6 +602,9 @@ class SongsTableView(ItemViewNoScrollMixin, QTableView):
         self.setMouseTracking(True)
         self.setEditTriggers(QAbstractItemView.SelectedClicked)
         self.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        # Note that the selection behavior affects drop behavior.
+        # You may need to to change the Model.flags and mimeData methods
+        # if you want to change this behavior.
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.setShowGrid(False)
         self.setDragEnabled(True)
